@@ -2,7 +2,11 @@
 Parameters to access Airbus data
 """
 
-class AirbusURL():
+
+class AirbusURL:
+    """
+    AIRBUS URLs
+    """
     PRICES = "https://data.api.oneatlas.airbus.com/api/v1/prices"
     ORDERS = "https://data.api.oneatlas.airbus.com/api/v1/orders"
     SEARCH = "https://search.foundation.api.oneatlas.airbus.com/api/v2/opensearch?constellation=SPOT"
@@ -10,16 +14,27 @@ class AirbusURL():
     ACCOUNT = "https://data.api.oneatlas.airbus.com/api/v1/me"
     ROLES = "https://data.api.oneatlas.airbus.com/api/v1/me/services"
 
+
 # Types are defined at: https://www.geoapi-airbusds.com/api-catalog-v2/oad-living-library/tutorials/#order-an-individual-product
 
-class AirbusProductType():
+
+class AirbusProductType:
+    """
+    Airbus product types
+    """
     MULTISPECTRAL = "multiSpectral"
 
 
-class AirbusRadiometricProcessing():
+class AirbusRadiometricProcessing:
+    """
+    Airbus radiometric processing
+    """
     REFLECTANCE = "REFLECTANCE"
 
 
-class AirbusImageFormat():
+class AirbusImageFormat:
+    """
+    Airbus image format
+    """
     GEOTIFF = "image/geotiff"
     JP2 = "image/jp2"
