@@ -1,7 +1,8 @@
-from .stac.dataframe import STACDataFrame  # , read_stac
+"""
+Curation module
+"""
 
+from .stac.dataframe import STACDataFrame  # , read_stac
 from .stac.stac import STACGenerator
-from .folder_formatters import SHFolderFormatter
-from .stac.utils import format_time_acquired, merge_stac_catalogs
 from .stac.parsers import STACIdParser, StructuredParser, UnestructuredParser
 from .stac.dataframe_labeling import UnlabeledStrategy, LabeledStrategy
