@@ -1,4 +1,8 @@
+"""
+STAC module
+"""
+
 # from .stac import STACGenerator
 # from .utils import format_time_acquired
 # from .parsers import STACIdParser, StructuredParser, UnestructuredParser
-from .dataframe import STACDataFrame, read_stac
\ No newline at end of file
+from .dataframe import STACDataFrame, read_stac
