@@ -9,13 +9,17 @@ import pandas as pd
 
 
 class STACExtensionObject:
+    """
+    Base model for STAC extensions objects
+    """
     def __init__(self) -> None:
         super().__init__()
-        self.properties = dict()
+        self.properties = {}
 
     def add_extension_to_object(
-        self, obj: Union[pystac.Item, pystac.Asset],
-        obj_info: Optional[pd.DataFrame] = None
+        self,
+        obj: Union[pystac.Item, pystac.Asset],
+        obj_info: Optional[pd.DataFrame] = None,
     ) -> Union[pystac.Item, pystac.Asset]:
         """
         Add the extension to the given object
@@ -23,4 +27,4 @@ class STACExtensionObject:
         :param obj: object to add the extension
         :param obj_info: object info from the STACDataFrame
         """
-        pass
+        return
