@@ -1,3 +1,7 @@
+"""
+STAC label extension module
+"""
+
 from .base import LabelExtensionObject
 from .image_name_labeler import ImageNameLabeler
-from .scaneo import ScaneoLabeler
\ No newline at end of file
+from .scaneo import ScaneoLabeler
