@@ -1,24 +1,26 @@
-'''
+"""
 Module for projection STAC extensions object
-'''
+"""
+
+from typing import Union
 
 import pystac
 import pandas as pd
 import rasterio
 
-from typing import Union
-from .base import STACExtensionObject
 from pystac.extensions.projection import ProjectionExtension
-
+from .base import STACExtensionObject
 
 
 class ProjExtensionObject(STACExtensionObject):
+    """
+    Projection extension object
+    """
     def __init__(self) -> None:
         super().__init__()
 
     def add_extension_to_object(
-        self, obj: Union[pystac.Item, pystac.Asset],
-        obj_info: pd.DataFrame
+        self, obj: Union[pystac.Item, pystac.Asset], obj_info: pd.DataFrame
     ) -> Union[pystac.Item, pystac.Asset]:
         """
         Add the extension to the given object
@@ -31,12 +33,12 @@ class ProjExtensionObject(STACExtensionObject):
             return obj
         elif isinstance(obj, pystac.Item):
             proj_ext = ProjectionExtension.ext(obj, add_if_missing=True)
-            ds = rasterio.open(obj_info['image'].values[0])
+            ds = rasterio.open(obj_info["image"].values[0])
             # Assume all the bands have the same projection
             proj_ext.apply(
                 epsg=ds.crs.to_epsg(),
                 transform=ds.transform,
                 shape=ds.shape,
-                )
+            )
 
         return obj
