@@ -1,3 +1,3 @@
 from .retrieve import retrieve_datasets  # , retrieve_dataset, list_datasets
 from .ingest import ingest_dataset
-from .download import download_dataset  # , download_file_url
+from .download import download_dataset, download_file_url
