@@ -20,9 +20,13 @@ class AuthRepo:
         if os.path.exists(self.creds_path):
             with open(self.creds_path, "r") as f:
                 creds = json.load(f)
-            user = self.decode_token(creds)
-            user["id_token"] = creds["id_token"]
-            return user
+            if not "id_token" in creds and not "api_key" in creds:
+                return None
+            if "api_key" in creds and creds["api_key"] != os.getenv(
+                "EOTDL_API_KEY", None
+            ):
+                return None
+            return creds
         return None
 
     def decode_token(self, token_data):
